<?php

namespace wpie\import\Downloader;

if ( ! defined( 'ABSPATH' ) ) {
        die( __( "Can't load this file directly", 'wp-import-export-lite' ) );
}

class File_Header {

        private $url;
        private $type;

        public function __construct( $url = "", $type = "file" ) {
                $this->url = $url;
                $this->type = $type;
        }

        public function get_filename() {

                $headers = $this->get_headers();

                if ( is_wp_error( $headers ) ) {
                        return $headers;
                }

                return $this->generate_filename( $headers );
        }

        private function get_headers() {

                $headers = @get_headers( $this->url, 1 );

                if ( ! is_array( $headers ) ) {
                        return new \WP_Error( 'wpie_error', __( "File Download Error : Invalid response headers", 'wp-import-export-lite' ) );
                }

                $data = [];
                $status = "";

                foreach ( $headers as $key => $value ) {
                        if ( is_int( $key ) ) {
                                $status = $value;
                                continue;
                        } elseif ( is_array( $value ) ) {
                                $value = end( $value );
                        }
                        $key = strtolower( $key );

                        preg_replace( '#(\s+)#i', ' ', $value );

                        $data[ $key ] = $value;
                }

                $status_code = 0;
                if ( preg_match( '#^HTTP/(1\.\d)[ \t]+(\d+)#i', $status, $matches ) ) {
                        $status_code = isset( $matches[ 2 ] ) && ! empty( $matches[ 2 ] ) ? intval( $matches[ 2 ] ) : 0;
                }

                $data[ "status" ] = $status_code;

                if ( $status_code !== 200 ) {
                        $error = get_status_header_desc( $status_code );
                        if ( empty( $error ) ) {
                                $error = sprintf( __( "File Download Error : %s invalid http response status code", 'wp-import-export-lite' ), $status_code );
                        }
                        return new \WP_Error( 'wpie_error', $error );
                }

                return $data;
        }

        private function generate_filename( $headers = [] ) {

                //get headers data
                $content_disposition = isset( $headers[ 'content-disposition' ] ) ? $headers[ 'content-disposition' ] : "";
                $content_type = isset( $headers[ 'content-type' ] ) ? $headers[ 'content-type' ] : "";

                //get ext from headers
                $ext = $this->get_ext_from_content_type( $content_type );
                $ext = empty( $ext ) ? "" : strtolower( trim( $ext ) );

                $url_data = parse_url( $this->url );
                $url_path = isset( $url_data[ 'path' ] ) ? $url_data[ 'path' ] : "";
                $path_info = trim( $url_path ) !== "" ? pathinfo( $url_path ) : pathinfo( $this->url );
                $new_ext = isset( $path_info[ 'extension' ] ) && ! empty( $path_info[ 'extension' ] ) ? strtolower( trim( $path_info[ 'extension' ] ) ) : "";
                $new_filename = "";

                if ( trim( $ext ) !== "" && $ext === 'jpeg' && $new_ext === 'jpg' ) {
                        $ext = $new_ext;
                }

                if ( trim( $ext ) !== "" && $new_ext === $ext ) {

                        $_filename = isset( $path_info[ 'filename' ] ) && ! empty( $path_info[ 'filename' ] ) ? preg_replace( "/[^a-z0-9\_\-\.]/i", '', preg_replace( '#[ -]+#', '-', $path_info[ 'filename' ] ) ) : "";
                        $new_filename = empty( $_filename ) ? "" : $_filename . '.' . strtolower( trim( $new_ext ) );
                }

                if ( empty( $new_filename ) ) {

                        //get filename from headers
                        $filename = $this->get_filename_from_content_disposition( $content_disposition );

                        $new_filename = time() . uniqid();

                        if ( trim( $ext ) !== "" && (trim( $new_ext ) === "" || strtolower( trim( $new_ext ) ) !== strtolower( trim( $ext ) ) ) ) {
                                $new_ext = strtolower( trim( $ext ) );
                        }
                        if ( trim( $filename ) !== "" ) {
                                $new_filename = $filename;
                        }

                        if ( trim( $new_ext ) === "" && trim( $new_filename ) !== "" ) {
                                $new_ext = pathinfo( $new_filename, PATHINFO_EXTENSION );
                        }

                        if ( trim( $new_ext ) !== "" ) {

                                $temp_ext = pathinfo( $new_filename, PATHINFO_EXTENSION );

                                if ( strtolower( trim( $new_ext ) ) !== strtolower( trim( $temp_ext ) ) ) {
                                        $new_filename = pathinfo( $new_filename, PATHINFO_FILENAME ) . "." . $new_ext;
                                }
                        }

                        $new_filename = preg_replace( "/[^a-z0-9\_\-\.]/i", '', preg_replace( '#[ -]+#', '-', $new_filename ) );

                        if ( trim( $new_filename ) === "" ) {
                                $new_filename = time() . uniqid() . "." . $new_ext;
                        }
                }

                if ( ! $this->is_valid_file( $new_filename ) ) {
                        return new \WP_Error( 'wpie_error', __( "File Download Error : Invalid File Format", 'wp-import-export-lite' ) );
                }

                return $new_filename;
        }

        private function get_filename_from_content_disposition( $content_disposition = "" ) {

                if ( empty( $content_disposition ) ) {
                        return "";
                }

                $regex = '/.*?filename=(?<fn>[^\s]+|\x22[^\x22]+\x22)\x3B?.*$/m';

                $new_file_data = null;

                $original_name = "";

                if ( preg_match( $regex, $content_disposition, $new_file_data ) ) {

                        if ( isset( $new_file_data[ 'fn' ] ) && ! empty( $new_file_data[ 'fn' ] ) ) {
                                $wp_filetype = wp_check_filetype( $new_file_data[ 'fn' ] );
                                if ( isset( $wp_filetype[ 'ext' ] ) && ( ! empty( $wp_filetype[ 'ext' ] )) && isset( $wp_filetype[ 'type' ] ) && ( ! empty( $wp_filetype[ 'type' ] )) ) {
                                        $original_name = $new_file_data[ 'fn' ];
                                }
                        }
                }

                if ( empty( $original_name ) ) {

                        $regex = '/.*filename=([\'\"]?)([^\"]+)\1/';

                        if ( preg_match( $regex, $content_disposition, $new_file_data ) ) {

                                if ( isset( $new_file_data[ '2' ] ) && ! empty( $new_file_data[ '2' ] ) ) {
                                        $wp_filetype = wp_check_filetype( $new_file_data[ '2' ] );
                                        if ( isset( $wp_filetype[ 'ext' ] ) && ( ! empty( $wp_filetype[ 'ext' ] )) && isset( $wp_filetype[ 'type' ] ) && ( ! empty( $wp_filetype[ 'type' ] )) ) {
                                                $original_name = $new_file_data[ '2' ];
                                        }
                                }
                        }
                }

                return $original_name;
        }

        private function get_ext_from_content_type( $content_type = "" ) {

                $content_type = strtolower( trim( $content_type ) );

                if ( $content_type === "" ) {
                        return "";
                }

                if ( $this->type === "file" ) {
                        return $this->get_file_ext( $content_type );
                }

                return $this->get_image_ext( $content_type );
        }

        private function get_file_ext( $content_type = "" ) {

                $ext = "";

                if ( strpos( $content_type, "text/xml" ) !== false || strpos( $content_type, "application/xml" ) !== false ) {
                        $ext = "xml";
                } elseif ( strpos( $content_type, "text/plain" ) !== false ) {
                        $ext = "txt";
                } elseif ( strpos( $content_type, "text/csv" ) !== false ) {
                        $ext = "csv";
                } elseif ( strpos( $content_type, 'application/vnd.openxmlformats-officedocument.spreadsheetml.sheet' ) !== false ) {
                        $ext = "xlsx";
                } elseif ( strpos( $content_type, 'application/vnd.ms-excel' ) !== false ) {
                        $ext = "xls";
                } elseif ( strpos( $content_type, 'json' ) !== false ) {
                        $ext = "json";
                } elseif ( strpos( $content_type, 'zip' ) !== false ) {
                        $ext = "zip";
                } elseif ( strpos( $content_type, 'application/vnd.oasis.opendocument.spreadsheet' ) !== false ) {
                        $ext = "ods";
                }

                return $ext;
        }

        private function get_image_ext( $content_type = "" ) {

                $ext = "";

                if ( strpos( $content_type, "jpe" ) !== false ) {
                        $ext = "jpeg";
                } elseif ( strpos( $content_type, "jpg" ) !== false ) {
                        $ext = "jpg";
                } elseif ( strpos( $content_type, "gif" ) !== false ) {
                        $ext = "gif";
                } elseif ( strpos( $content_type, "png" ) !== false ) {
                        $ext = "png";
                } elseif ( strpos( $content_type, 'bmp' ) !== false ) {
                        $ext = "bmp";
                } elseif ( strpos( $content_type, 'tif' ) !== false ) {
                        $ext = "tiff";
                } elseif ( strpos( $content_type, 'icon' ) !== false ) {
                        $ext = "ico";
                }

                return $ext;
        }

        private function is_valid_file( $filename = "" ) {

                if ( $this->type === "file" && ! preg_match( '%\W(xml|zip|csv|xls|xlsx|xml|ods|txt|json)$%i', trim( $filename ) ) ) {

                        return false;
                } elseif ( $this->type === "image" && ! preg_match( '%\W(jpe|jpeg|jpg|gif|png|bmp|tiff|ico)$%i', trim( $filename ) ) ) {

                        return false;
                }

                return true;
        }

        public function __destruct() {
                foreach ( $this as $key => $value ) {
                        unset( $this->$key );
                }
        }

}
